# eid-image-extractor

## Introduction

This is a small python script to extract the image from a Belgian electronic
identity card.

## How to install

```
pip install eid-image-extractor
```

## How to use

```
eid-image-extractor
```
After this, if everything went well, you will see a file with the name
```{NATIONAL_NUMBER}.jpg``` in the current directory.
